summaryrefslogtreecommitdiffstats
path: root/kdat/Archive.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kdat/Archive.cpp')
-rw-r--r--kdat/Archive.cpp8
1 files changed, 4 insertions, 4 deletions
diff --git a/kdat/Archive.cpp b/kdat/Archive.cpp
index ad66dbd..5e8ef65 100644
--- a/kdat/Archive.cpp
+++ b/kdat/Archive.cpp
@@ -94,7 +94,7 @@ void Archive::read( int version )
}
}
// Number of immediate tqchildren (4 bytes).
fread( &ival, sizeof( ival ), 1, _fptr );
//===== Read files =====
@@ -148,7 +148,7 @@ void Archive::write( FILE* fptr )
fwrite( &ival, sizeof( ival ), 1, _fptr );
}
// Number of immediate tqchildren (4 bytes).
ival = getChildren().count();
fwrite( &ival, sizeof( ival ), 1, _fptr );
@@ -202,7 +202,7 @@ const TQPtrList<File>& Archive::getChildren()
{
read();
- return _tqchildren;
+ return _children;
}
const TQPtrList<Range>& Archive::getRanges()
@@ -255,7 +255,7 @@ void Archive::addChild( File* file )
{
read();
- _tqchildren.append( file );
+ _children.append( file );
}
File* Archive::addFile( int size, int mtime, int startRecord, int endRecord, const TQString & filename )
@@ -94,7 +94,7 @@ void Archive::read( int version )
}
}
- // Number of immediate tqchildren (4 bytes).
+ // Number of immediate children (4 bytes).
fread( &ival, sizeof( ival ), 1, _fptr );
//===== Read files =====
@@ -148,7 +148,7 @@ void Archive::write( FILE* fptr )
fwrite( &ival, sizeof( ival ), 1, _fptr );
}
- // Number of immediate tqchildren (4 bytes).
+ // Number of immediate children (4 bytes).
ival = getChildren().count();
fwrite( &ival, sizeof( ival ), 1, _fptr );